"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var util_1 = require("../../util");
var definitions_interface_1 = require("../../definitions.interface");
var configurations_definitions_interface_1 = require("../../configurations-definitions.interface");
/**
 * @stable [22.10.2018]
 * @param {IUniversalApplicationStoreEntity} storeEntity
 * @returns {IUniversalApplicationStoreEntity}
 */
exports.applicationMapper = function (storeEntity) { return ({
    application: __assign({}, storeEntity.application),
}); };
/* @stable - 22.04.2018 */
exports.dictionariesMapper = function (storeEntity) { return ({
    dictionaries: __assign({}, storeEntity.dictionaries),
}); };
/* @stable - 16.04.2018 */
exports.userMapper = function (storeEntity) { return ({
    user: __assign({}, storeEntity.user),
}); };
/* @stable - 16.04.2018 */
exports.transportMapper = function (storeEntity) { return ({
    transport: __assign({}, storeEntity.transport),
}); };
/**
 * @stable [29.05.2018]
 * @param {IEditableEntity} editableEntity
 * @returns {IFilterFormWrapperEntity}
 */
exports.filterFormMapper = function (editableEntity) { return ({
    filterForm: __assign({}, editableEntity),
}); };
/**
 * @stable [14.06.2018]
 * @param {IEditableEntity} editableEntity
 * @returns {IEditableEntityFormWrapperEntity}
 */
exports.formMapper = function (editableEntity) { return ({
    form: __assign({}, editableEntity),
}); };
/**
 * @stable [16.05.2018]
 * @param {IListEntity} listEntity
 * @param {IDataMutatorEntity} dataMutator
 * @returns {IListWrapperEntity}
 */
exports.listMapper = function (listEntity, dataMutator) {
    var list = __assign({}, listEntity);
    if (!R.isNil(dataMutator) && !R.isNil(list.data) && list.data.length > 0) {
        if (!R.isNil(dataMutator.sorter)) {
            list.data = R.sort(dataMutator.sorter, list.data);
        }
        if (!R.isNil(dataMutator.filter)) {
            list.totalCount = (list.data = R.filter(dataMutator.filter, list.data)).length;
        }
    }
    return { list: list };
};
/**
 * @stable [16.05.2018]
 * @param {IListEntity} listEntity
 * @param {IDataMutatorEntity} dataMutator
 * @returns {IMutatedListWrapperEntity}
 */
exports.mutatedListMapper = function (listEntity, dataMutator) {
    return {
        mutatedList: exports.listMapper(listEntity, dataMutator).list,
    };
};
/**
 * @stable [09.05.2018]
 * @param {IListEntity} listEntity
 * @param {number} pageSize
 * @returns {IPagedEntity}
 */
exports.listEntityPageEntityFilterMapper = function (listEntity, pageSize) {
    if (pageSize === void 0) { pageSize = definitions_interface_1.DEFAULT_PAGE_SIZE; }
    return ({
        page: listEntity.lockPage ? listEntity.page : definitions_interface_1.FIRST_PAGE,
        pageSize: pageSize,
    });
};
/**
 * @stable [09.05.2018]
 * @param {IListWrapperEntity} listEntity
 * @param {number} pageSize
 * @returns {IPagedEntity}
 */
exports.listEntityWrapperPageEntityFilterMapper = function (listEntity, pageSize) {
    if (pageSize === void 0) { pageSize = definitions_interface_1.DEFAULT_PAGE_SIZE; }
    return exports.listEntityPageEntityFilterMapper(listEntity.list, pageSize);
};
/**
 * @stable [16.05.2018]
 * @param {IListWrapperEntity} listWrapperEntity
 * @param {IDataMutatorEntity} dataMutator
 * @returns {IListWrapperEntity}
 */
exports.listWrapperMapper = function (listWrapperEntity, dataMutator) {
    return exports.listMapper(listWrapperEntity.list, dataMutator);
};
/**
 * @stable [31.08.2018]
 * @param {ITabPanelEntity} tabPanel
 * @returns {ITabPanelEntity}
 */
exports.tabPanelMapper = function (tabPanel) { return ({ tabPanel: __assign({}, tabPanel) }); };
/**
 * @stable [30.08.2018]
 * @param {ITabPanelWrapperEntity} tabPanelWrapperEntity
 * @returns {ITabPanelWrapperEntity}
 */
exports.tabPanelWrapperMapper = function (tabPanelWrapperEntity) {
    return exports.tabPanelMapper(tabPanelWrapperEntity.tabPanel);
};
/**
 * @stable [31.08.2018]
 * @param {ITabPanelEntity} tabPanel
 * @returns {number}
 */
exports.tabPanelActiveValueMapper = function (tabPanel) { return tabPanel.activeValue; };
/**
 * @stable [31.08.2018]
 * @param {ITabPanelWrapperEntity} tabPanelWrapperEntity
 * @returns {number}
 */
exports.tabPanelWrapperActiveValueMapper = function (tabPanelWrapperEntity) {
    return exports.tabPanelActiveValueMapper(tabPanelWrapperEntity.tabPanel);
};
/**
 * @stable [05.08.2018]
 * @param {IFilterFormWrapperEntity} filterFormWrapperEntity
 * @param {boolean} useFormMapper
 * @returns {TResult}
 */
exports.filterFormWrapperMapper = function (filterFormWrapperEntity, useFormMapper) {
    if (useFormMapper === void 0) { useFormMapper = false; }
    return (useFormMapper ? exports.formMapper : exports.filterFormMapper)(filterFormWrapperEntity.filterForm);
};
/**
 * @stable [05.08.2018]
 * @param {IFilterFormWrapperEntity} filterFormWrapperEntity
 * @returns {TResult}
 */
exports.filterFormChangesWrapperMapper = function (filterFormWrapperEntity) {
    return (__assign({}, filterFormWrapperEntity.filterForm.changes));
};
/**
 * @stable [29.10.2018]
 * @param {IFormWrapperEntity} formWrapperEntity
 * @returns {TResult}
 */
exports.formChangesWrapperMapper = function (formWrapperEntity) {
    return (__assign({}, formWrapperEntity.form.changes));
};
/**
 * @stable [03.12.2018]
 * @param {IEditableEntity} editableEntity
 * @returns {TResult}
 */
exports.editableEntityChangesMapper = function (editableEntity) {
    return (__assign({}, editableEntity.changes));
};
/**
 * @stable [05.08.2018]
 * @param {IQueryFilterWrapperEntity} queryFilterWrapperEntity
 * @returns {IQueryWrapper}
 */
exports.filterQueryWrapperMapper = function (queryFilterWrapperEntity) {
    return ({
        query: util_1.trimmedUndefEmpty(queryFilterWrapperEntity.filter.query),
    });
};
/**
 * @stable [19.12.2018]
 * @param {IListWrapperEntity} entity
 * @returns {IFilterConfiguration}
 */
exports.refreshedListWrapperEntityMapper = function (entity) { return (__assign({ actions: [{ type: configurations_definitions_interface_1.ToolbarActionEnum.REFRESH_DATA }] }, exports.actionsDisabledListWrapperEntityMapper(entity))); };
/**
 * @stable [16.05.2018]
 * @param {IListWrapperEntity} listWrapperEntity
 * @param {IDataMutatorEntity} dataMutator
 * @returns {IMutatedListWrapperEntity}
 */
exports.mutatedListWrapperMapper = function (listWrapperEntity, dataMutator) {
    return exports.mutatedListMapper(listWrapperEntity.list, dataMutator);
};
/* @stable - 12.04.2018 */
exports.entityMapper = function (entity, formEntity) {
    return ({
        entity: __assign({}, entity, formEntity && formEntity.changes),
        entityId: util_1.orNull(entity, function () { return entity.id; }),
        originalEntity: __assign({}, entity),
        newEntity: !entity || R.isNil(entity.id),
    });
};
/**
 * @stable [09.05.2018]
 * @param {IListEntity} listEntity
 * @returns {TEntity}
 */
exports.selectedEntityMapper = function (listEntity) {
    return util_1.orNull(listEntity, function () { return listEntity.selected; });
};
/**
 * @stable [09.05.2018]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {TEntity}
 */
exports.listSelectedEntityMapper = function (listWrapperEntity) {
    return exports.selectedEntityMapper(listWrapperEntity.list);
};
/* @stable - 12.04.2018 */
exports.listWrapperSelectedEntityMapper = function (listWrapperState, formEntity) {
    return exports.entityMapper(exports.listSelectedEntityMapper(listWrapperState), formEntity);
};
/**
 * @stable [19.12.2018]
 * @param {IListEntity} listEntity
 * @returns {IDisabledWrapper}
 */
exports.disabledListEntityMapper = function (listEntity) { return ({
    disabled: listEntity.progress,
}); };
/**
 * @stable [29.05.2018]
 * @param {IListEntity} listEntity
 * @returns {IFilterConfiguration}
 */
exports.actionsDisabledListEntityMapper = function (listEntity) { return ({
    actionsDisabled: listEntity.progress,
}); };
/**
 * @stable [29.05.2018]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {IFilterConfiguration}
 */
exports.actionsDisabledListWrapperEntityMapper = function (listWrapperEntity) {
    return exports.actionsDisabledListEntityMapper(listWrapperEntity.list);
};
/**
 * @stable [19.12.2018]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {IDisabledWrapper}
 */
exports.disabledListWrapperEntityMapper = function (listWrapperEntity) {
    return exports.disabledListEntityMapper(listWrapperEntity.list);
};
/**
 * @stable [31.08.2018]
 * @param {TEntity[] | TEntity} data
 * @param {IFilterAndSorterConfiguration} config
 * @returns {Array<ISelectOptionEntity<TEntity extends IOptionEntity>>}
 */
exports.selectOptionsMapper = function (data, config) {
    var entities = util_1.filterAndSortEntities(data, config);
    return util_1.orNull(!R.isNil(entities), function () { return (entities.map(function (entity) {
        return util_1.defValuesFilter({
            value: entity.id,
            label: entity.name,
            disabled: entity.disabled,
            rawData: entity,
        });
    })); });
};
/**
 * @stable [16.06.2018]
 * @param {IDictionaryEntity<TDictionaryEntity>} dictionaryEntity
 * @param {IFilterAndSorterConfiguration} config
 * @returns {Array<ISelectOptionEntity<TDictionaryEntity>>}
 */
exports.dictionaryEntityMapper = function (dictionaryEntity, config) {
    return exports.selectOptionsMapper(exports.dictionaryEntityDataMapper(dictionaryEntity), config);
};
/**
 * @stable [29.06.2018]
 * @param {IDictionaryEntity<TDictionaryEntity>} dictionaryEntity
 * @param {(data: (TDictionaryEntity[] | TDictionaryEntity)) => (TDictionaryEntity[] | TDictionaryEntityResult[] | TDictionaryEntity)} accessor
 * @returns {TDictionaryEntity[] | TDictionaryEntityResult[] | TDictionaryEntity}
 */
exports.dictionaryEntityDataMapper = function (dictionaryEntity, accessor) {
    return util_1.orNull(dictionaryEntity, function () { return util_1.isFn(accessor) && !R.isNil(dictionaryEntity.data)
        ? accessor(dictionaryEntity.data)
        : dictionaryEntity.data; });
};
/**
 * @stable [23.11.2018]
 * @param {TEntity} entity
 * @returns {TEntity}
 */
exports.simpleEntityMapper = function (entity) {
    return util_1.orNull(!R.isNil(entity), __assign({}, entity));
};
/**
 * @stable [29.05.2018]
 */
exports.universalDefaultMappers = [
    exports.transportMapper,
    exports.userMapper,
    exports.dictionariesMapper
];
//# sourceMappingURL=universal-connector.mapper.js.map