"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var button_1 = require("../button");
var util_1 = require("../../util");
var base_1 = require("../base");
var Dialog = /** @class */ (function (_super) {
    __extends(Dialog, _super);
    /**
     * @stable [04.10.2018]
     * @param {TProps} props
     */
    function Dialog(props) {
        var _this = _super.call(this, props) || this;
        _this.onAccept = _this.onAccept.bind(_this);
        _this.onClose = _this.onClose.bind(_this);
        return _this;
    }
    /**
     * @stable [03.08.2018]
     * @returns {JSX.Element}
     */
    Dialog.prototype.render = function () {
        var props = this.props;
        return (React.createElement("div", { ref: 'self', className: this.getDialogClassName() },
            this.getDialogBody(),
            React.createElement("div", { className: this.uiFactory.dialogScrim })));
    };
    /**
     * @stable [17.05.2018]
     */
    Dialog.prototype.activate = function (callback) {
        // Each plugin must override this method
    };
    /**
     * @stable [17.05.2018]
     */
    Dialog.prototype.onAccept = function () {
        var props = this.props;
        if (props.onAccept) {
            props.onAccept();
        }
    };
    /**
     * @stable [17.05.2018]
     */
    Dialog.prototype.onClose = function () {
        var props = this.props;
        if (props.onClose) {
            props.onClose();
        }
    };
    Object.defineProperty(Dialog.prototype, "acceptable", {
        /**
         * @stable [17.05.2018]
         * @returns {boolean}
         */
        get: function () {
            return this.props.acceptable !== false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Dialog.prototype, "closable", {
        /**
         * @stable [17.05.2018]
         * @returns {boolean}
         */
        get: function () {
            return this.props.closable !== false;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [04.10.2018]
     * @returns {JSX.Element}
     */
    Dialog.prototype.getDialogBody = function () {
        var _this = this;
        var props = this.props;
        var dialogBodyEl = this.getDialogBodyElement();
        return (React.createElement("div", { className: util_1.toClassName('rac-dialog-container', this.uiFactory.dialogContainer, props.autoWidth && 'rac-dialog-container-auto-width') },
            React.createElement("div", { className: this.uiFactory.dialogSurface },
                React.createElement("h2", { className: util_1.toClassName('rac-dialog-title', this.uiFactory.dialogTitle) }, this.t(props.title || this.settings.messages.dialogTitleMessage)),
                util_1.orNull(!R.isNil(dialogBodyEl) || !R.isNil(props.message), React.createElement("div", { className: util_1.toClassName('rac-dialog-content', this.uiFactory.dialogContent) }, dialogBodyEl || this.t(props.message))),
                util_1.orNull(this.closable || this.acceptable, function () { return (React.createElement("footer", { className: util_1.toClassName('rac-dialog-actions-footer', _this.uiFactory.dialogActions) },
                    util_1.orNull(_this.closable, function () { return (React.createElement(button_1.Button, { icon: false, disabled: _this.isCloseButtonDisabled(), onClick: _this.onClose }, _this.t(props.closeMessage || _this.settings.messages.dialogCancelMessage))); }),
                    util_1.orNull(_this.acceptable, function () { return (React.createElement(button_1.Button, { icon: false, disabled: _this.isAcceptButtonDisabled(), onClick: _this.onAccept }, _this.t(props.acceptMessage || _this.settings.messages.dialogAcceptMessage))); }))); }))));
    };
    /**
     * @stable [05.08.2018]
     * @returns {string}
     */
    Dialog.prototype.getDialogClassName = function () {
        return util_1.toClassName('rac-dialog', this.props.className, this.uiFactory.dialog);
    };
    /**
     * @stable [03.08.2018]
     * @returns {boolean}
     */
    Dialog.prototype.isCloseButtonDisabled = function () {
        return this.props.closeDisabled;
    };
    /**
     * @stable [03.08.2018]
     * @returns {boolean}
     */
    Dialog.prototype.isAcceptButtonDisabled = function () {
        return this.props.acceptDisabled;
    };
    /**
     * @stable [03.08.2018]
     * @returns {React.ReactNode}
     */
    Dialog.prototype.getDialogBodyElement = function () {
        return this.props.children;
    };
    /**
     * @stable [04.08.2018]
     * @returns {boolean}
     */
    Dialog.prototype.isDialogVisible = function () {
        return true;
    };
    Dialog.defaultProps = {
        autoWidth: true,
    };
    return Dialog;
}(base_1.BaseComponent));
exports.Dialog = Dialog;
//# sourceMappingURL=dialog.component.js.map