"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var ts_smart_logger_1 = require("ts-smart-logger");
var textfield_1 = require("../textfield");
var util_1 = require("../../../util");
var dnd_1 = require("../../dnd");
var multifield_1 = require("../multifield");
var multifield_2 = require("../multifield");
var dialog_1 = require("../../dialog");
var web_camera_1 = require("../../web-camera");
var BaseFileField = /** @class */ (function (_super) {
    __extends(BaseFileField, _super);
    /**
     * @stable [30.06.2018]
     * @param {TProps} props
     */
    function BaseFileField(props) {
        var _this = _super.call(this, props) || this;
        _this.multiFieldPlugin = new multifield_1.MultiFieldPlugin(_this);
        _this.filesMap = new Map();
        _this.onSelect = _this.onSelect.bind(_this);
        _this.onCameraDialogClose = _this.onCameraDialogClose.bind(_this);
        _this.onCameraDialogAccept = _this.onCameraDialogAccept.bind(_this);
        _this.doSelectBlob = _this.doSelectBlob.bind(_this);
        _this.openFileDialog = _this.openFileDialog.bind(_this);
        _this.downloadFile = _this.downloadFile.bind(_this);
        _this.openCameraDialog = _this.openCameraDialog.bind(_this);
        var actions = [
            util_1.orNull(props.useCamera, function () { return ({ type: 'video', onClick: _this.openCameraDialog }); }),
            { type: 'attach_file', onClick: _this.openFileDialog },
            util_1.orNull(props.useDownloadAction, function () { return ({ type: 'cloud_download', onClick: _this.downloadFile }); })
        ];
        _this.defaultActions = R.insertAll(0, actions.filter(function (cfg) { return !R.isNil(cfg); }), _this.defaultActions);
        return _this;
    }
    /**
     * @stable [28.06.2018]
     */
    BaseFileField.prototype.componentWillUnmount = function () {
        var _this = this;
        _super.prototype.componentWillUnmount.call(this);
        this.filesMap.forEach(function (value, key) { return _this.destroyBlob(key); });
    };
    /**
     * @stable [28.06.2018]
     * @param {IKeyboardEvent} event
     */
    BaseFileField.prototype.onKeyEnter = function (event) {
        _super.prototype.onKeyEnter.call(this, event);
        this.openFileDialog(event);
    };
    /**
     * @stable [28.06.2018]
     * @param {IKeyboardEvent} event
     */
    BaseFileField.prototype.onKeyBackspace = function (event) {
        _super.prototype.onKeyBackspace.call(this, event);
        this.clearValue();
    };
    BaseFileField.prototype.clearValue = function () {
        var activeValue = this.multiFieldPlugin.activeValue[0];
        if (!R.isNil(activeValue)) {
            var currentValue = activeValue.id;
            this.destroyBlob(currentValue);
            this.multiFieldPlugin.onDeleteItem({ id: currentValue });
        }
    };
    /**
     * @stable [28.06.2018]
     * @param {IBasicEvent} event
     */
    BaseFileField.prototype.onClick = function (event) {
        _super.prototype.onClick.call(this, event);
        this.openFileDialog(event);
    };
    /**
     * @stable [03.08.2018]
     * @returns {JSX.Element}
     */
    BaseFileField.prototype.getAttachmentElement = function () {
        var _this = this;
        var state = this.state;
        var props = this.props;
        var messages = this.settings.messages;
        var dndElement = (React.createElement(dnd_1.DnD, { ref: 'dnd', disabled: this.isFieldInactive(), onSelect: this.onSelect }));
        if (!props.useCamera) {
            return dndElement;
        }
        return (React.createElement("div", { className: 'rac-dnd-wrapper' },
            dndElement,
            React.createElement(dialog_1.Dialog, { ref: 'cameraDialog', title: messages.takeSnapshotMessage, acceptMessage: messages.acceptMessage, onClose: this.onCameraDialogClose, onAccept: this.onCameraDialogAccept }, util_1.orNull(state.cameraEnabled, function () { return (React.createElement(web_camera_1.WebCamera, { ref: 'camera', onSelect: _this.doSelectBlob })); }))));
    };
    /**
     * @stable [02.08.2018]
     * @returns {EntityIdT[]}
     */
    BaseFileField.prototype.getEmptyValue = function () {
        return [];
    };
    /**
     * @stable [05.10.2018]
     * @returns {string}
     */
    BaseFileField.prototype.getFieldClassName = function () {
        return util_1.toClassName(_super.prototype.getFieldClassName.call(this), 'rac-filefield');
    };
    /**
     * @stable [02.08.2018]
     */
    BaseFileField.prototype.onCameraDialogClose = function () {
        this.setState({ cameraEnabled: false });
    };
    /**
     * @stable [02.08.2018]
     */
    BaseFileField.prototype.onCameraDialogAccept = function () {
        this.camera.capture();
        this.onCameraDialogClose();
    };
    /**
     * @stable [19.12.2018]
     * @param {File[]} file
     */
    BaseFileField.prototype.onSelect = function (file) {
        if (!this.props.multi) {
            this.clearValue();
        }
        this.doSelectBlob(file[0]);
    };
    /**
     * @stable [02.08.2018]
     * @param {Blob} blob
     */
    BaseFileField.prototype.doSelectBlob = function (blob) {
        var fileUrl = URL.createObjectURL(blob);
        this.filesMap.set(fileUrl, blob);
        this.multiFieldPlugin.onAddItem({ id: fileUrl });
        this.setFocus();
    };
    Object.defineProperty(BaseFileField.prototype, "dnd", {
        get: function () {
            return this.refs.dnd;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [02.08.2018]
     * @param {IBasicEvent} event
     */
    BaseFileField.prototype.openCameraDialog = function (event) {
        util_1.cancelEvent(event);
        this.setState({ cameraEnabled: true });
        this.cameraDialog.activate();
    };
    /**
     * @stable [28.06.2018]
     * @param {IBasicEvent} event
     */
    BaseFileField.prototype.openFileDialog = function (event) {
        util_1.cancelEvent(event);
        this.dnd.open();
    };
    /**
     * @stable [28.06.2018]
     * @param {IBasicEvent} event
     */
    BaseFileField.prototype.downloadFile = function (event) {
        util_1.cancelEvent(event);
        var url = multifield_2.toLastAddedMultiItemEntity(this.value);
        util_1.downloadBlob(url, this.props.fileName || url);
    };
    /**
     * @stable [28.06.2018]
     * @param {EntityIdT} key
     */
    BaseFileField.prototype.destroyBlob = function (key) {
        URL.revokeObjectURL(key);
        this.filesMap.delete(key);
        BaseFileField.logger.debug("[$BasicFileField][destroyBlob] The blob has been destroyed to the key " + key);
    };
    Object.defineProperty(BaseFileField.prototype, "cameraDialog", {
        /**
         * @stable [02.08.2018]
         * @returns {IUniversalDialog}
         */
        get: function () {
            return this.refs.cameraDialog;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseFileField.prototype, "camera", {
        /**
         * @stable [02.08.2018]
         * @returns {IWebCamera}
         */
        get: function () {
            return this.refs.camera;
        },
        enumerable: true,
        configurable: true
    });
    BaseFileField.logger = ts_smart_logger_1.LoggerFactory.makeLogger('BaseFileField');
    return BaseFileField;
}(textfield_1.BasicTextField));
exports.BaseFileField = BaseFileField;
//# sourceMappingURL=base-filefield.component.js.map