"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var util_1 = require("../../../util");
var multifield_support_1 = require("./multifield.support");
var MultiFieldPlugin = /** @class */ (function () {
    /**
     * @stable [28.11.2018]
     * @param {ICrossPlatformField} field
     */
    function MultiFieldPlugin(field) {
        this.field = field;
    }
    /**
     * @stable [01.06.2018]
     * @param {IMultiItemEntity} item
     */
    MultiFieldPlugin.prototype.onAddItem = function (item) {
        this.onChangeManually(this.toChangesPayload(this.onAdd(item)));
    };
    /**
     * @stable [01.07.2018]
     * @param {IMultiItemEntity} item
     */
    MultiFieldPlugin.prototype.onMergeItem = function (item) {
        if (item.newEntity) {
            this.onAddItem(item);
        }
        else {
            this.onEditItem(item);
        }
    };
    /**
     * @stable [01.06.2018]
     * @param {IMultiItemEntity} item
     */
    MultiFieldPlugin.prototype.onEditItem = function (item) {
        this.onChangeManually(this.toChangesPayload(this.onEdit(item)));
    };
    /**
     * @stable [01.06.2018]
     * @param {IMultiItemEntity} item
     */
    MultiFieldPlugin.prototype.onDeleteItem = function (item) {
        this.onChangeManually(this.toChangesPayload(this.onDelete(item)));
    };
    MultiFieldPlugin.prototype.onAdd = function (item) {
        var removeValue = this.removeValue;
        var addValue = this.addValue;
        var editArray = this.editValue;
        var removeLen = removeValue.length;
        var removeArray = removeValue.filter((function (removeItem) { return removeItem.id !== item.id; }));
        var addArray = addValue;
        if (removeArray.length === removeLen) {
            addArray = addValue.concat(multifield_support_1.fromMultiItemEntityToEntity(item));
        }
        return { addArray: addArray, removeArray: removeArray, editArray: editArray };
    };
    /**
     * @stable [11.08.2018]
     * @param {IMultiItemEntity} item
     * @returns {IMultiFieldChangesEntity}
     */
    MultiFieldPlugin.prototype.onEdit = function (item) {
        return multifield_support_1.toMultiFieldChangesEntityOnEdit(item, this.addValue, this.removeValue, this.editValue, this.originalValue);
    };
    /**
     * @stable [18.08.2018]
     * @param {IMultiItemEntity} item
     * @returns {IMultiFieldChangesEntity}
     */
    MultiFieldPlugin.prototype.onDelete = function (item) {
        return multifield_support_1.toMultiFieldChangesEntityOnDelete(item, this.addValue, this.removeValue, this.editValue, this.originalValue);
    };
    Object.defineProperty(MultiFieldPlugin.prototype, "originalValue", {
        /**
         * @stable [23.06.2018]
         * @returns {IMultiItemEntity[]}
         */
        get: function () {
            return multifield_support_1.extractMultiSourceItemEntities(this.value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MultiFieldPlugin.prototype, "activeValue", {
        /**
         * @stable [01.06.2018]
         * @returns {IMultiItemEntity[]}
         */
        get: function () {
            return multifield_support_1.toActualMultiItemEntities({
                source: this.originalValue,
                remove: this.removeValue,
                add: this.addValue,
                edit: this.editValue,
            });
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [02.06.2018]
     * @param {MultiFieldEntityT} value
     * @returns {number}
     */
    MultiFieldPlugin.prototype.getActiveValueLength = function (value) {
        return multifield_support_1.toActualMultiItemEntitiesLength(value);
    };
    Object.defineProperty(MultiFieldPlugin.prototype, "editValue", {
        /**
         * @stable [04.07.2018]
         * @returns {IMultiItemEntity[]}
         */
        get: function () {
            return multifield_support_1.extractMultiEditItemEntities(this.value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MultiFieldPlugin.prototype, "addValue", {
        /**
         * @stable [04.07.2018]
         * @returns {IEntity[]}
         */
        get: function () {
            return multifield_support_1.extractMultiAddItemEntities(this.value);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [01.06.2018]
     * @param {MultiFieldEntityT} payload
     */
    MultiFieldPlugin.prototype.onChangeManually = function (payload) {
        this.field.onChangeManually(payload, this.getActiveValueLength(payload));
    };
    /**
     * @stable [01.06.2018]
     * @param {IMultiFieldChangesEntity} result
     * @returns {MultiFieldEntityT}
     */
    MultiFieldPlugin.prototype.toChangesPayload = function (result) {
        var add = result.addArray;
        var remove = result.removeArray;
        var edit = result.editArray;
        if (add.length || remove.length || edit.length) {
            return { add: add, remove: remove, edit: edit, source: this.originalValue };
        }
        else {
            return this.originalValue;
        }
    };
    Object.defineProperty(MultiFieldPlugin.prototype, "removeValue", {
        /**
         * @stable [23.06.2018]
         * @returns {IMultiItemEntity[]}
         */
        get: function () {
            return multifield_support_1.extractMultiRemoveItemEntities(this.value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MultiFieldPlugin.prototype, "value", {
        /**
         * @stable [28.11.2018]
         * @returns {MultiFieldEntityT}
         */
        get: function () {
            var field = this.field;
            return util_1.isFn(field.getValue) ? field.getValue() : field.value;
        },
        enumerable: true,
        configurable: true
    });
    return MultiFieldPlugin;
}());
exports.MultiFieldPlugin = MultiFieldPlugin;
//# sourceMappingURL=multifield.plugin.js.map