"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var util_1 = require("../../util");
var router_1 = require("../../router");
var stack_1 = require("../stack");
var action_builder_1 = require("../../component/action.builder");
/**
 * @stable [02.07.2018]
 * @param {IEditedListMiddlewareConfig<TEntity extends IEntity, TApplicationState>} config
 * @returns {IEffectsAction[]}
 */
exports.makeCreateEntityMiddleware = function (config) {
    var action = config.action;
    return [
        stack_1.StackActionBuilder.buildLockAction(util_1.isFn(config.formSection)
            ? config.formSection(null, config.state, action)
            : config.formSection),
        router_1.RouterActionBuilder.buildNavigateAction(util_1.isFn(config.path)
            ? config.path(null, config.state, action)
            : config.path)
    ];
};
/**
 * @stable [02.07.2018]
 * @param {IEditedListMiddlewareConfig<TEntity extends IEntity, TApplicationState>} config
 * @returns {IEffectsAction[]}
 */
exports.makeSelectEntityMiddleware = function (config) {
    var action = config.action;
    var payloadWrapper = action.initialData || action.data;
    var selected = payloadWrapper.selected;
    if (config.useLazyLoading) {
        return [
            action_builder_1.ListActionBuilder.buildLazyLoadAction(config.listSection, { selected: selected })
        ];
    }
    return [
        stack_1.StackActionBuilder.buildLockAction(util_1.isFn(config.formSection)
            ? config.formSection(selected, config.state, action)
            : config.formSection),
        router_1.RouterActionBuilder.buildNavigateAction(util_1.isFn(config.path)
            ? config.path(selected, config.state, action)
            : config.path)
    ];
};
//# sourceMappingURL=edited-list.middleware.js.map