"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var stack_helper_1 = require("./stack.helper");
describe('stack.helper', function () {
    describe('getDestroyableSections', function () {
        it('test1', function () {
            var destroyableSections = stack_helper_1.getDestroyableSections('section1', {
                stack: [
                    {
                        section: 'section2',
                        linkedToSections: ['section3'],
                    }
                ],
            });
            expect(destroyableSections).toEqual(['section2', 'section3']);
        });
        it('test2', function () {
            var destroyableSections = stack_helper_1.getDestroyableSections('section1', {
                stack: [
                    {
                        section: 'section2',
                        linkedToSections: ['section3'],
                    },
                    {
                        section: 'section3',
                        linkedToSections: ['section4'],
                    }
                ],
            });
            expect(destroyableSections).toEqual(['section2', 'section3', 'section4']);
        });
        it('test3', function () {
            var destroyableSections = stack_helper_1.getDestroyableSections('section2', {
                stack: [
                    {
                        section: 'section2',
                        linkedToSections: ['section3'],
                    }
                ],
            });
            expect(destroyableSections).toEqual([]);
        });
        it('test4', function () {
            var destroyableSections = stack_helper_1.getDestroyableSections('section3', {
                stack: [
                    {
                        section: 'section2',
                        linkedToSections: ['section3'],
                    }
                ],
            });
            expect(destroyableSections).toEqual([]);
        });
        it('test5', function () {
            var destroyableSections = stack_helper_1.getDestroyableSections('section2', {
                stack: [
                    {
                        section: 'section2',
                        linkedToSections: ['section3', 'section5'],
                    },
                    {
                        section: 'section3',
                        linkedToSections: ['section4', 'section6'],
                    }
                ],
            });
            expect(destroyableSections).toEqual([]);
        });
        it('test6', function () {
            var destroyableSections = stack_helper_1.getDestroyableSections('section3', {
                stack: [
                    {
                        section: 'section2',
                        linkedToSections: ['section3', 'section5'],
                    },
                    {
                        section: 'section3',
                        linkedToSections: ['section4', 'section7'],
                    },
                    {
                        section: 'section4',
                        linkedToSections: [],
                    },
                    {
                        section: 'section5',
                        linkedToSections: [],
                    },
                    {
                        section: 'section6',
                        linkedToSections: [],
                    },
                    {
                        section: 'section7',
                        linkedToSections: [],
                    }
                ],
            });
            expect(destroyableSections).toEqual(['section6']);
        });
        it('test7', function () {
            var destroyableSections = stack_helper_1.getDestroyableSections('section1', {
                stack: [
                    {
                        section: 'section2',
                        linkedToSections: [],
                    }
                ],
            });
            expect(destroyableSections).toEqual(['section2']);
        });
    });
    describe('lockNextSection', function () {
        it('test1', function () {
            var nextState = stack_helper_1.lockNextSection('nextSection2', {
                stack: [
                    {
                        section: 'section1',
                        linkedToSections: [],
                    }
                ],
            });
            expect(nextState).toEqual([{ section: 'section1', linkedToSections: ['nextSection2'] }]);
        });
        it('test2', function () {
            var nextState = stack_helper_1.lockNextSection('nextSection3', {
                stack: [
                    {
                        section: 'section1',
                        linkedToSections: ['nextSection2'],
                    }
                ],
            });
            expect(nextState).toEqual([{ section: 'section1', linkedToSections: ['nextSection2', 'nextSection3'] }]);
        });
        it('test3', function () {
            var nextState = stack_helper_1.lockNextSection('nextSection3', {
                stack: [
                    {
                        section: 'section1',
                        linkedToSections: ['section2'],
                    },
                    {
                        section: 'section2',
                        linkedToSections: [],
                    }
                ],
            });
            expect(nextState).toEqual([
                { section: 'section1', linkedToSections: ['section2'] },
                { section: 'section2', linkedToSections: ['nextSection3'] }
            ]);
        });
    });
    describe('destroySections', function () {
        it('test1', function () {
            var nextState = stack_helper_1.destroySections(['section1', 'section2'], {
                stack: [
                    {
                        section: 'section1',
                        linkedToSections: [],
                    },
                    {
                        section: 'section2',
                        linkedToSections: [],
                    },
                    {
                        section: 'section3',
                        linkedToSections: [],
                    },
                    {
                        section: 'section4',
                        linkedToSections: [],
                    }
                ],
            });
            expect(nextState).toEqual([
                {
                    section: 'section3',
                    linkedToSections: [],
                },
                {
                    section: 'section4',
                    linkedToSections: [],
                }
            ]);
        });
    });
    describe('pushNextSection', function () {
        it('test1', function () {
            var nextState = stack_helper_1.pushNextSection('section2', {
                stack: [
                    {
                        section: 'section1',
                        linkedToSections: [],
                    },
                    {
                        section: 'section2',
                        linkedToSections: [],
                    }
                ],
            });
            expect(nextState).toEqual([
                {
                    section: 'section1',
                    linkedToSections: [],
                },
                {
                    section: 'section2',
                    linkedToSections: [],
                }
            ]);
        });
        it('test2', function () {
            var nextState = stack_helper_1.pushNextSection('section2', {
                stack: [
                    {
                        section: 'section1',
                        linkedToSections: [],
                    }
                ],
            });
            expect(nextState).toEqual([
                {
                    section: 'section1',
                    linkedToSections: [],
                },
                {
                    section: 'section2',
                    linkedToSections: [],
                }
            ]);
        });
    });
});
//# sourceMappingURL=stack.helper.spec.js.map