"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var graphlib = require("@dagrejs/graphlib");
var R = require("ramda");
/**
 * @stable [18.09.2018]
 * @param {IStackEntity} stackEntity
 * @returns {string[][]}
 */
exports.toGraphComponents = function (stackEntity) {
    var gr = new graphlib.Graph();
    stackEntity.stack.forEach(function (entry) {
        gr.setNode(entry.section);
        entry.linkedToSections.forEach(function (linkedSection) {
            gr.setNode(linkedSection);
            gr.setEdge(entry.section, linkedSection);
        });
    });
    return graphlib.alg.components(gr);
};
/**
 * @stable [18.09.2018]
 * @param {IStackEntity} stackEntity
 * @param {string} currentSection
 * @returns {Set<string>}
 */
exports.toAllDependentSections = function (stackEntity, currentSection) {
    var allDependentSections = new Set();
    var graphComponents = exports.toGraphComponents(stackEntity);
    graphComponents.forEach(function (graphComponent) {
        if (R.isNil(currentSection) || R.contains(currentSection, graphComponent)) {
            graphComponent.forEach(function (entry) { return allDependentSections.add(entry); });
        }
    });
    return allDependentSections;
};
//# sourceMappingURL=stack.support.js.map