import { Reducer, ReducersMapObject, AnyAction } from 'redux';
import { IEffectsAction } from 'redux-effects-promise';
import { IKeyValue } from '../definitions.interface';
export declare type FilterT = (action: IEffectsAction) => boolean;
/**
 * @stable - 10.04.2018
 * @param {string} customSection
 * @returns {FilterT}
 */
export declare function reducerSectionFilter(customSection: string): FilterT;
/**
 * @stable - 10.04.2018
 * @param {Reducer<S>} reducer
 * @param {FilterT} filterObject
 * @returns {Reducer<S>}
 */
export declare const filter: <S>(reducer: Reducer<S>, filterObject: FilterT) => Reducer<S>;
/**
 * @stable - 10.04.2018
 * @param {Reducer<S>} reducer
 * @param {string} customSection
 * @returns {Reducer<S>}
 */
export declare const filterBySection: <S>(reducer: Reducer<S>, customSection: string) => Reducer<S>;
/**
 * @stable - 15.04.2018
 * @param {TReducersMap} reducersMap
 * @returns {Reducer<ReducersMapObject>}
 */
export declare const composeReducers: <TReducersMap extends {}>(reducersMap: TReducersMap) => Reducer<ReducersMapObject>;
/**
 * @stable [11.08.2018]
 * @param {string} updateActionType
 * @param {string} destroyActionType
 * @param {TKeyValue} initialState
 * @returns {(state: TKeyValue, action: AnyAction) => TKeyValue}
 */
export declare const entityReducerFactory: <TKeyValue extends IKeyValue>(updateActionType: string, destroyActionType: string, initialState?: TKeyValue) => (state: TKeyValue, action: AnyAction) => TKeyValue;
