"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var Promise = require("bluebird");
var $ = require("jquery");
var R = require("ramda");
var type_1 = require("./type");
var env_1 = require("../env");
var calc_1 = require("./calc");
var definitions_interface_1 = require("../definitions.interface");
var googleMapsScriptTask;
/**
 * @stable [14.06.2018]
 * @param {string} tag
 * @param {Element} parent
 * @returns {TElement}
 */
exports.createElement = function (tag, parent) {
    if (tag === void 0) { tag = 'div'; }
    if (parent === void 0) { parent = document.body; }
    var el = document.createElement(tag);
    exports.addChild(el, parent);
    return el;
};
/**
 * @stable [21.11.2018]
 * @param {Partial<HTMLScriptElement>} cfg
 * @returns {Bluebird<HTMLScriptElement>}
 */
exports.createScript = function (cfg) {
    return new Promise(function (resolve) {
        var el = exports.createElement('script');
        el.type = 'text/javascript';
        el.onload = function () { return resolve(el); };
        Object.assign(el, cfg);
    });
};
/**
 * @stable [12.09.2018]
 * @param {{} | HTMLScriptElement} cfg
 * @param {string} libraries
 * @returns {Bluebird<HTMLScriptElement>}
 */
exports.getGoogleMapsScript = function (cfg, libraries) {
    if (libraries === void 0) { libraries = 'places'; }
    return googleMapsScriptTask = googleMapsScriptTask || exports.createScript(__assign({}, cfg, { src: "https://maps.googleapis.com/maps/api/js?key=" + env_1.ENV.googleMapsKey + "&libraries=" + libraries }));
};
/**
 * @stable [30.07.2018]
 * @param {Element} element
 * @param {string} clsName
 */
exports.addClassNameToElement = function (element) {
    var clsName = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        clsName[_i - 1] = arguments[_i];
    }
    var _a;
    return (_a = element.classList).add.apply(_a, clsName);
};
/**
 * @stable [30.10.2018]
 * @param {Element} element
 * @param {string} clsName
 */
exports.removeClassNameFromElement = function (element) {
    var clsName = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        clsName[_i - 1] = arguments[_i];
    }
    var _a;
    return (_a = element.classList).remove.apply(_a, clsName);
};
/**
 * @stable [01.10.2018]
 * @param {string} rootId
 */
exports.addRootElement = function (rootId) {
    var rootEl = exports.createElement();
    rootEl.setAttribute('id', rootId);
    exports.addClassNameToElement(rootEl, 'rac-root', 'rac-flex');
};
/**
 * @stable [14.11.2018]
 * @param {string} clsName
 */
exports.addClassNameToBody = function () {
    var clsName = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        clsName[_i] = arguments[_i];
    }
    return exports.addClassNameToElement.apply(void 0, [document.body].concat(clsName));
};
/**
 * @stable [28.06.2018]
 * @param {Element} child
 * @param {Element} parent
 * @returns {Element}
 */
exports.addChild = function (child, parent) {
    if (parent === void 0) { parent = document.body; }
    return parent.appendChild(child);
};
/**
 * @stable [28.06.2018]
 * @param {Element} child
 * @param {Element} parent
 * @returns {Element}
 */
exports.removeChild = function (child, parent) {
    if (parent === void 0) { parent = document.body; }
    return parent.removeChild(child);
};
/**
 * @stable [17.11.2018]
 * @param {Element} child
 * @param {Element} parent
 * @returns {Element}
 */
exports.removeSelf = function (child, parent) {
    if (parent === void 0) { parent = document.body; }
    return exports.removeChild(child, child.parentElement);
};
/**
 * @stable [14.06.2018]
 * @param {string} images
 */
exports.createPreloadedImg = function () {
    var images = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        images[_i] = arguments[_i];
    }
    var preloadedWrapper = exports.createElement();
    preloadedWrapper.style.width = '0px';
    preloadedWrapper.style.height = '0px';
    images.forEach(function (src) {
        var el = exports.createElement('img', preloadedWrapper);
        el.src = src;
        el.style.height = '0px';
        el.style.width = '0px';
    });
};
/**
 * @stable [04.10.2018]
 * @param {Element} source
 * @param {number | (() => number)} left
 * @param {number | (() => number)} top
 */
exports.setAbsoluteOffsetByCoordinates = function (source, left, top) {
    exports.applyStyle(source, 'position', 'absolute');
    exports.applyStyle(source, 'left', calc_1.calc(left) + "px");
    exports.applyStyle(source, 'top', calc_1.calc(top) + "px");
};
/**
 * @stable [04.10.2018]
 * @param {Element} source
 * @param {string} style
 * @param {AnyT} value
 * @returns {any}
 */
exports.applyStyle = function (source, style, value) { return $(source).css(style, value); };
/**
 * @stable [04.10.2018]
 * @param {Element} source
 * @returns {number}
 */
exports.getWidth = function (source) { return $(source).width(); };
/**
 * @stable [18.11.2018]
 * @param {Element} source
 * @param {number} width
 * @returns {any}
 */
exports.setWidth = function (source, width) { return $(source).width(width); };
/**
 * @stable [27.10.2018]
 * @param {Element} source
 * @returns {number}
 */
exports.getHeight = function (source) { return $(source).height(); };
/**
 * @stable [27.10.2018]
 * @param {Element} source
 * @returns {number}
 */
exports.getContentHeight = function (source) { return $(source).children().height(); };
/**
 * @stable [01.12.2018]
 * @param {Element} source
 * @returns {number}
 */
exports.getScrollLeft = function (source) { return $(source).scrollLeft(); };
/**
 * @stable [01.12.2018]
 * @param {Element} source
 * @returns {number}
 */
exports.getScrollTop = function (source) { return $(source).scrollTop(); };
/**
 * @stable [01.12.2018]
 * @param {Element} source
 * @param {number} value
 * @returns {IJQueryElement}
 */
exports.setScrollTop = function (source, value) { return $(source).scrollTop(value); };
/**
 * @stable [18.12.2018]
 * @param {Element} source
 * @param {number} value
 * @returns {IJQueryElement}
 */
exports.setScrollLeft = function (source, value) { return $(source).scrollLeft(value); };
/**
 * @stable [04.10.2018]
 * @param {Element} source
 * @returns {boolean}
 */
exports.isParentDocumentBody = function (source) { return $(source).parent().get(0) === document.body; };
/**
 * @stable [23.06.2018]
 * @returns {boolean}
 */
exports.isDocumentHasFocus = function () { return type_1.isFn(document.hasFocus) && document.hasFocus(); };
/**
 * @stable [13.12.2018]
 * @param {Element} source
 * @returns {IJQueryElement}
 */
exports.toJqEl = function (source) { return $(source); };
/**
 * @stable [28.06.2018]
 * @param {string} fileName
 * @param {Blob} blob
 */
exports.downloadFile = function (fileName, blob) {
    var url = URL.createObjectURL(blob);
    try {
        var loader = exports.createElement('a');
        exports.addClassNameToElement(loader, 'rac-invisible');
        loader.href = url;
        loader.download = fileName;
        loader.click();
        exports.removeChild(loader);
    }
    finally {
        URL.revokeObjectURL(url);
    }
};
/**
 * @stable [12.09.2018]
 * @param {string} path
 * @param {string} target
 */
exports.downloadAnchoredFile = function (path, target) {
    if (target === void 0) { target = '_blank'; }
    var link = exports.createElement('a');
    link.href = path;
    link.target = target;
    link.click();
};
/**
 * @stable [03.09.2018]
 * @param {HTMLElement} el
 * @returns {boolean}
 */
exports.isElementFocused = function (el) { return document.activeElement === el; };
/**
 * @stable [19.09.2018]
 * @param {string} v
 * @returns {number}
 */
exports.parseValueAtPx = function (v) { return parseFloat((v || '').split('px')[0] || '0'); };
/**
 * @stable [30.07.2018]
 * @returns {() => boolean}
 */
exports.preventContextMenu = function () { return document.body.oncontextmenu = function () { return false; }; };
/**
 * @stable [01.12.2018]
 * @param {string} selector
 * @param {Element} parent
 * @returns {Element}
 */
exports.findElement = function (selector, parent) {
    if (parent === void 0) { parent = document.body; }
    return $(parent).find(selector)[0];
};
/**
 * @stable [01.12.2018]
 * @param {Element} parent
 * @returns {Element}
 */
exports.findUniversalSelectedElement = function (parent) {
    if (parent === void 0) { parent = document.body; }
    return exports.findElement("." + definitions_interface_1.UNIVERSAL_SELECTED_ELEMENT_SELECTOR, parent);
};
/**
 * @stable [01.12.2018]
 * @param {Element} element
 * @param {IXYEntity} xyEntity
 */
exports.scrollTo = function (element, xyEntity) { return element.scrollTo(xyEntity.x, xyEntity.y); };
/**
 * @stable [13.12.2018]
 * @param {IStickyElementPayloadEntity} payloadEntity
 */
exports.setStickyElementProperties = function (payloadEntity) {
    if (R.isNil(payloadEntity)) {
        return;
    }
    var position;
    var zIndex;
    var top;
    var marginTop;
    var selfTop = payloadEntity.jqSelfEl.offset().top;
    var selfScrollTop = payloadEntity.jqSelfEl.scrollTop();
    if (selfScrollTop >= payloadEntity.initialStickyElTop - selfTop) {
        position = 'absolute';
        zIndex = 1;
        top = selfScrollTop - payloadEntity.initialStickyElTop + selfTop;
        marginTop = payloadEntity.jqStickyEl.height();
    }
    else {
        position = 'initial';
        zIndex = 0;
        top = 0;
        marginTop = 0;
    }
    payloadEntity.jqStickyEl.css({ position: position, 'z-index': zIndex, top: top });
    payloadEntity.jqStickyNeighborRightEl.css('margin-top', marginTop + "px");
};
/**
 * @stable [13.12.2018]
 * @param {IJQueryElement} jqSelfEl
 * @returns {IStickyElementPayloadEntity}
 */
exports.getStickyElementInitialProperties = function (jqSelfEl) {
    var jqStickyEl = jqSelfEl.find("." + definitions_interface_1.UNIVERSAL_STICKY_ELEMENT_SELECTOR);
    if (!R.isNil(jqStickyEl) && !R.isNil(jqStickyEl.val())) {
        return {
            jqSelfEl: jqSelfEl,
            jqStickyEl: jqStickyEl,
            jqStickyNeighborRightEl: $(jqStickyEl.siblings()[0]),
            jqStickyElHeight: jqStickyEl.height(),
            initialStickyElTop: jqStickyEl.offset().top,
        };
    }
    return null;
};
//# sourceMappingURL=dom.js.map