import { AnyT, IKeyValue, IEntity } from '../definitions.interface';
import { IFilterAndSorterConfiguration } from '../configurations-definitions.interface';
export declare type KeyPredicateT = (key: string, value: AnyT) => boolean;
export declare type ValuePredicateT = (value: AnyT) => boolean;
export declare function cloneUsingFilters<TSource extends IKeyValue, TResult extends IKeyValue>(source: TSource, ...predicates: KeyPredicateT[]): TResult;
/**
 * @stable [11.08.2018]
 * @param {TSource} source
 * @param {KeyPredicateT} predicates
 * @returns {TResult}
 */
export declare const filterByPredicate: <TSource extends IKeyValue, TResult extends IKeyValue>(source: TSource, ...predicates: KeyPredicateT[]) => TResult;
export declare function excludeFieldsPredicateFactory(...fields: string[]): (key: string, value: any) => boolean;
export declare const EXCLUDE_ID_FIELD_PREDICATE: (key: string, value: any) => boolean;
export declare const EXCLUDE_EFFECTOR_FIELD_PREDICATE: (key: string, value: any) => boolean;
export declare const EXCLUDE_TIME_FIELDS_PREDICATE: (key: string, value: any) => boolean;
/**
 * @test
 * @param {TSource} source
 * @returns {TResult}
 */
export declare function cloneUsingTimeFieldsFilters<TSource extends IKeyValue, TResult extends IKeyValue>(source: TSource): TResult;
export declare const OBJECT_VALUE_PREDICATE: (key: string, value: any) => boolean;
export declare const NOT_OBJECT_VALUE_PREDICATE: (key: string, value: any) => boolean;
export declare const NOT_PROGRESS_FIELD_PREDICATE: (key: string, value: any) => boolean;
export declare const NOT_PASSWORD_FIELD_PREDICATE: (key: string, value: any) => boolean;
/**
 * @stable [03.10.2018]
 * @param {string} key
 * @param {AnyT} value
 * @returns {boolean}
 * @constructor
 */
export declare const DEF_KEY_VALUE_PREDICATE: (key: string, value: any) => boolean;
/**
 * @stable [03.10.2018]
 * @param {AnyT} value
 * @returns {boolean}
 * @constructor
 */
export declare const DEF_VALUE_PREDICATE: (value: any) => boolean;
/**
 * @stable [27.10.2018]
 * @param {AnyT} value
 * @returns {boolean}
 * @constructor
 */
export declare const NOT_NIL_VALUE_PREDICATE: (value: any) => boolean;
/**
 * @stable [19.12.2018]
 * @param {AnyT} value
 * @returns {boolean}
 * @constructor
 */
export declare const TRUE_VALUE_PREDICATE: (value: any) => boolean;
/**
 * @stable [03.10.2018]
 * @param {TValue[]} data
 * @param {ValuePredicateT} predicates
 * @returns {TValue[]}
 */
export declare const filterArray: <TValue>(data: TValue[], ...predicates: ValuePredicateT[]) => TValue[];
/**
 * @stable [10.11.2018]
 * @param {TValue} data
 * @returns {TValue[]}
 */
export declare const defValuesArrayFilter: <TValue>(...data: TValue[]) => TValue[];
/**
 * @stable [29.11.2018]
 * @param {TValue} data
 * @returns {TValue[]}
 */
export declare const notNilValuesArrayFilter: <TValue>(...data: TValue[]) => TValue[];
/**
 * @stable [19.12.2018]
 * @param {TValue} data
 * @returns {TValue[]}
 */
export declare const trueValuesArrayFilter: <TValue>(...data: TValue[]) => TValue[];
export declare function excludeFieldsFilter<TSource extends IKeyValue, TResult extends IKeyValue>(source: TSource, ...fields: string[]): TResult;
export declare const defValuesFilter: <TSource extends IKeyValue, TResult extends IKeyValue>(source: TSource) => TResult;
export declare const excludeIdFieldFilter: <TSource extends IKeyValue, TResult extends IKeyValue>(source: TSource) => TResult;
export declare const excludeEffectorFieldFilter: <TSource extends IKeyValue, TResult extends IKeyValue>(source: TSource) => TResult;
/**
 * @stable [16.06.2018]
 * @param {TEntity[] | TEntity} data
 * @param {IFilterAndSorterConfiguration} config
 * @returns {TEntity[]}
 */
export declare const filterAndSortEntities: <TEntity = IEntity>(data: TEntity | TEntity[], config?: IFilterAndSorterConfiguration) => TEntity[];
/**
 * @stable [08.06.2018]
 * @param {string} query
 * @param {EntityIdT} items
 * @returns {boolean}
 */
export declare const queryFilter: (query: string, ...items: (string | number)[]) => boolean;
